emgfit API docs
===============

emgfit.ame\_funcs module
------------------------

.. automodule:: emgfit.ame_funcs
   :members:
   :undoc-members:
   :show-inheritance:

emgfit.config module
--------------------

.. automodule:: emgfit.config
   :members:
   :undoc-members:
   :show-inheritance:

emgfit.emg\_funcs module
------------------------

.. automodule:: emgfit.emg_funcs
   :members:
   :undoc-members:
   :show-inheritance:

emgfit.fit\_models module
-------------------------

.. automodule:: emgfit.fit_models
   :members:
   :undoc-members:
   :show-inheritance:

emgfit.spectrum module
----------------------

.. automodule:: emgfit.spectrum
   :members:
   :undoc-members:
   :private-members: spectrum._eval_peakshape_errors
   :show-inheritance:
